@@ -204,7 +204,7 @@ class BaseAnnotator(object):
                 for coldef in self.conf['output_columns']]
         cols[0] = 'base__hugo'
         gene_collection = {}
-        for d in cf.get_variant_iterator_filtered_uids_cols(cols):
+        for d in cf.exec_db(cf.get_variant_iterator_filtered_uids_cols, cols):
             hugo = d['hugo']
             if hugo == None:
                 continue
