@@ -29,6 +29,9 @@ import glob
 import nest_asyncio
 nest_asyncio.apply()
 import re
+import sys
+if sys.platform == 'win32' and sys.version_info >= (3,8):
+    asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
 
 # Custom system conf
 pre_parser = argparse.ArgumentParser(add_help=False)
@@ -648,21 +651,31 @@ class Cravat (object):
                     if util.is_url(ip):
                         import requests
                         if not self.args.silent:
-                            print(f'Fetching {ip}... ', end='', flush=True)
+                            print(f'Fetching {ip}... ')
                         try:
-                            r = requests.get(ip, timeout=3)
-                            r.raise_for_status()
+                            r = requests.head(ip)
+                            r = requests.get(ip, stream=True)
                             fn = os.path.basename(ip)
                             fpath = fn
-                            wf = open(fpath, 'w')
-                            wf.write(r.text)
-                            wf.close()
+                            cur_size = 0.0
+                            num_total_star = 40.0
+                            total_size = float(r.headers['content-length'])
+                            with open(fpath, 'wb') as wf:
+                                for chunk in r.iter_content(chunk_size=8192):
+                                    wf.write(chunk)
+                                    cur_size += float(len(chunk))
+                                    perc = cur_size / total_size
+                                    cur_star = int(perc * num_total_star)
+                                    rem_stars = int(num_total_star - cur_star)
+                                    cur_prog = '*' * cur_star
+                                    rem_prog = ' ' * rem_stars
+                                    print(f'[{cur_prog}{rem_prog}] {util.humanize_bytes(cur_size)} / {util.humanize_bytes(total_size)} ({perc * 100.0:.0f}%)', end='\r', flush=True)
+                                    if cur_size == total_size:
+                                        print('\n')
                             self.inputs[input_no] = os.path.abspath(fpath)
                         except:
-                            print(f'unsuccessful. exiting.')
+                            print(f'File downloading unsuccessful. Exiting.')
                             exit()
-                        if not self.args.silent:
-                            print(f'done')
                     elif first_non_url_input is None:
                         first_non_url_input = ip
         else:
@@ -887,26 +900,37 @@ class Cravat (object):
         module = SimpleNamespace(title='Converter',
                                  name='converter',
                                  script_path=converter_path)
-        cmd = [module.script_path,
-                *self.inputs,
-               '-n', self.run_name,
-               '-d', self.output_dir,
-               '-l', self.input_assembly]
+        arg_dict = {
+            'path': module.script_path, 
+            'inputs': self.inputs,
+            'name': self.run_name,
+            'output_dir': self.output_dir,
+            'genome': self.input_assembly
+        }
+        arg_dict['conf'] = {}
+        for mn in self.conf._all:
+            if mn.endswith('-converter'):
+                arg_dict['conf'][mn] = self.conf._all[mn]
+        if 'run' in self.conf._all:
+            for mn in self.conf._all['run']:
+                if mn.endswith('-converter'):
+                    arg_dict['conf'][mn] = self.conf._all[mn]
         if module.name in self.cravat_conf:
             if module.name in self.modules_conf:
                 confs = json.dumps(self.modules_conf[module.name])
                 confs = "'" + confs.replace("'", '"') + "'"
-                cmd.extend(['--confs', confs])
+                arg_dict['confs'] = confs
         if self.args.forcedinputformat is not None:
-            cmd.extend(['-f', self.args.forcedinputformat])
+            arg_dict['format'] = self.args.forcedinputformat
         if self.args.unique_variants:
-            cmd.append('--unique-variants')
+            arg_dict['unique_variants'] = True
         self.announce_module(module)
         if self.verbose:
             if not self.args.silent:
-                print(' '.join(cmd))
+                print(' '.join([str(k) + '=' + str(v) for k, v in arg_dict.items()]))
+        arg_dict['status_writer'] = self.status_writer
         converter_class = util.load_class(module.script_path, 'MasterCravatConverter')
-        converter = converter_class(cmd, self.status_writer)
+        converter = converter_class(arg_dict)
         self.numinput, self.converter_format = converter.run()
 
     def run_genemapper (self):
@@ -1210,7 +1234,7 @@ class Cravat (object):
                     arg_dict['separatesample'] = True
                 if self.verbose:
                     if not self.args.silent:
-                        print(' '.join(arg_dict))
+                        print(' '.join([str(k) + '=' + str(v) for k, v in arg_dict.items()]))
                 arg_dict['status_writer'] = self.status_writer
                 arg_dict['reporttypes'] = [module_name.replace('reporter', '')]
                 Reporter = util.load_class(module.script_path, 'Reporter')
