@@ -6,7 +6,7 @@ import cravat.constants as constants
 
 class Reporter (CravatReport):
 
-    def __init__ (self, cmd_args, status_writer):
+    def __init__ (self, cmd_args, status_writer=None):
         self.no_log = True
         self.no_status_update = True
         super().__init__(cmd_args, status_writer)
@@ -15,11 +15,6 @@ class Reporter (CravatReport):
         self.data = {}
         self.keep_json_all_mapping = True
         self.conf = ConfigLoader()
-        cravat_conf = self.conf.get_cravat_conf()
-        if 'viewer_effective_digits' in cravat_conf:
-            self.viewer_effective_digits = cravat_conf['viewer_effective_digits']
-        else:
-            self.viewer_effective_digits = constants.viewer_effective_digits
         
     def write_preface (self, level):
         self.data[level] = []
@@ -28,10 +23,6 @@ class Reporter (CravatReport):
     
     def write_table_row (self, row):
         row = self.substitute_val(self.level, row)
-        for i in range(len(row)):
-            cell = row[i]
-            if type(cell) == float:
-                row[i] = round(cell, self.viewer_effective_digits)
         self.table.append(list(row))
     
     def end (self):
@@ -54,6 +45,6 @@ def test ():
         '--filterstring', '{"variant": {"thousandgenomes__af": ">0.1"}}'])
     data = reporter.run()
 
-if __name__ == '__main__':
+#if __name__ == '__main__':
     #main()
     test()
