@@ -25,10 +25,12 @@ from cravat import constants
 from cravat import get_live_annotator, get_live_mapper
 import signal
 import gzip
-from cravat.cravat_util import max_version_supported_for_migration
+from cravat.cravat_util import max_version_supported_for_migration, status_from_db
 import cravat.util
+import logging
 
 cfl = ConfigLoader()
+report_generation_ps = {}
 
 class FileRouter(object):
 
@@ -149,7 +151,7 @@ class FileRouter(object):
         run_name = os.path.basename(run_path)
         report_path = None
         if report_type in self.report_extensions:
-            ext = self.report_extensions.get(report_type, '.'+report_type)
+            ext = self.report_extensions.get(report_type, '.' + report_type)
             report_path = [run_path + ext]
         else:
             reporter = au.get_local_module_info(report_type + 'reporter')
@@ -214,9 +216,11 @@ class WebJob(object):
         self.info['open_cravat_version'] = ''
         self.info['num_input_var'] = ''
         self.info['submission_time'] = ''
+        self.info['reports_being_generated'] = []
         self.job_dir = job_dir
         self.job_status_fpath = job_status_fpath
-        self.info['id'] = os.path.basename(job_dir)
+        job_id = os.path.basename(job_dir)
+        self.info['id'] = job_id
 
     def save_job_options (self, job_options):
         self.set_values(**job_options)
@@ -464,6 +468,7 @@ async def get_job (request, job_id):
         status=job.info['status'],
     )
     existing_reports = []
+    reports_being_generated = []
     for report_type in get_valid_report_types():
         report_paths = await filerouter.job_report(request, job_id, report_type)
         if report_paths is not None:
@@ -474,6 +479,13 @@ async def get_job (request, job_id):
                     break
             if report_exist:
                 existing_reports.append(report_type)
+                global report_generation_ps
+                if job_id in report_generation_ps and report_type in report_generation_ps[job_id]:
+                    del report_generation_ps[job_id][report_type]
+            else:
+                if job_id in report_generation_ps and report_type in report_generation_ps[job_id]:
+                    reports_being_generated.append(report_type)
+    job.info['reports_being_generated'] = reports_being_generated
     job.set_info_values(reports=existing_reports)
     job.info['username'] = os.path.basename(os.path.dirname(job_dir))
     if 'open_cravat_version' not in job.info:
@@ -576,6 +588,7 @@ async def get_job_log (request):
 def get_valid_report_types():
     reporter_infos = au.get_local_module_infos(types=['reporter'])
     report_types = [x.name.split('reporter')[0] for x in reporter_infos]
+    report_types = [v for v in report_types if not v in ['text', 'pandas', 'stdout', 'example']]
     return report_types
 
 async def get_report_types(request):
@@ -592,10 +605,21 @@ async def generate_report(request):
     job_db_path = await filerouter.job_db(request, job_id)
     run_args = ['oc', 'report', job_db_path]
     run_args.extend(['-t', report_type])
-    p = await asyncio.create_subprocess_shell(' '.join(run_args))
-    await p.wait()
-    #await p.terminate()
-    return web.json_response('done')
+    if job_id not in report_generation_ps:
+        report_generation_ps[job_id] = {}
+    report_generation_ps[job_id][report_type] = True
+    p = await asyncio.create_subprocess_shell(' '.join(run_args), stderr=asyncio.subprocess.PIPE)
+    out, err = await p.communicate()
+    if report_type in report_generation_ps[job_id]:
+        del report_generation_ps[job_id][report_type]
+    if job_id in report_generation_ps and len(report_generation_ps[job_id]) == 0:
+        del report_generation_ps[job_id]
+    response = 'done'
+    if len(err) > 0:
+        logger = logging.getLogger()
+        logger.error(err.decode('utf-8'))
+        response = 'fail'
+    return web.json_response(response)
 
 async def download_report(request):
     global filerouter
@@ -1075,6 +1099,24 @@ async def update_result_db (request):
         msg = 'fail'
     return web.json_response(msg)
 
+async def import_job (request):
+    global filerouter
+    jobs_dirs = await filerouter.get_jobs_dirs(request)
+    jobs_dir = jobs_dirs[0]
+    job_id = get_next_job_id()
+    job_dir = os.path.join(jobs_dir, job_id)
+    os.makedirs(job_dir, exist_ok=True)
+    fn = request.headers['Content-Disposition'].split('filename=')[1]
+    dbpath = os.path.join(job_dir,fn)
+    with open(dbpath,'wb') as wf:
+        async for data, _ in request.content.iter_chunks():
+            wf.write(data)
+    status_d = status_from_db(dbpath)
+    status_path = dbpath + '.status.json'
+    with open(status_path,'w') as wf:
+        json.dump(status_d,wf)
+    return web.Response()
+
 filerouter = FileRouter()
 VIEW_PROCESS = None
 live_modules = None
@@ -1113,6 +1155,7 @@ routes.append(['POST', '/submit/annotate', get_live_annotation_post])
 routes.append(['GET', '/', redirect_to_index])
 routes.append(['GET', '/submit/jobs/{job_id}/status', get_job_status])
 routes.append(['GET', '/submit/updateresultdb', update_result_db])
+routes.append(['POST','/submit/import',import_job])
 
 if __name__ == '__main__':
     app = web.Application()
